<?php

namespace B2buy\Contact\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Contact\Http\Requests\B2buyRequest;
use B2buy\Contact\Models\B2buy;

/**
 * Admin web controller class.
 */
class B2buyWorkflowController extends BaseController
{

    /**
     * Workflow controller function for b2buy.
     *
     * @param Model   $b2buy
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(B2buyRequest $request, B2buy $b2buy, $step)
    {

        try {

            $b2buy->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('contact::b2buy.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/b2buy/b2buy/' . $b2buy->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/b2buy/b2buy/' . $b2buy->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for b2buy.
     *
     * @param Model   $b2buy
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(B2buy $b2buy, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $b2buy->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('contact::b2buy.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('contact::admin.b2buy.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('contact::admin.b2buy.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('contact::admin.b2buy.message', $data)->render();

        }

    }
}
