<?php

namespace B2buy\Contact\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use B2buy\Contact\Models\B2buy;

class B2buyPolicy
{

    /**
     * Determine if the given user can view the b2buy.
     *
     * @param UserPolicyInterface $authUser
     * @param B2buy $b2buy
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, B2buy $b2buy)
    {
        if ($authUser->canDo('contact.b2buy.view') && $authUser->isAdmin()) {
            return true;
        }

        return $b2buy->user_id == user_id() && $b2buy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a b2buy.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('contact.b2buy.create');
    }

    /**
     * Determine if the given user can update the given b2buy.
     *
     * @param UserPolicyInterface $authUser
     * @param B2buy $b2buy
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, B2buy $b2buy)
    {
        if ($authUser->canDo('contact.b2buy.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $b2buy->user_id == user_id() && $b2buy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given b2buy.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, B2buy $b2buy)
    {
        return $b2buy->user_id == user_id() && $b2buy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given b2buy.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, B2buy $b2buy)
    {
        if ($authUser->canDo('contact.b2buy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given b2buy.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, B2buy $b2buy)
    {
        if ($authUser->canDo('contact.b2buy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
