<?php

namespace B2buy\Contact\Workflow;

use B2buy\Contact\Models\B2buy;
use Validator;

class B2buyValidator
{

    /**
     * Determine if the given b2buy is valid for complete status.
     *
     * @param B2buy $b2buy
     *
     * @return bool / Validator
     */
    public function complete(B2buy $b2buy)
    {
        return Validator::make($b2buy->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given b2buy is valid for verify status.
     *
     * @param B2buy $b2buy
     *
     * @return bool / Validator
     */
    public function verify(B2buy $b2buy)
    {
        return Validator::make($b2buy->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given b2buy is valid for approve status.
     *
     * @param B2buy $b2buy
     *
     * @return bool / Validator
     */
    public function approve(B2buy $b2buy)
    {
        return Validator::make($b2buy->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given b2buy is valid for publish status.
     *
     * @param B2buy $b2buy
     *
     * @return bool / Validator
     */
    public function publish(B2buy $b2buy)
    {
        return Validator::make($b2buy->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given b2buy is valid for archive status.
     *
     * @param B2buy $b2buy
     *
     * @return bool / Validator
     */
    public function archive(B2buy $b2buy)
    {
        return Validator::make($b2buy->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given b2buy is valid for unpublish status.
     *
     * @param B2buy $b2buy
     *
     * @return bool / Validator
     */
    public function unpublish(B2buy $b2buy)
    {
        return Validator::make($b2buy->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
